summaryrefslogtreecommitdiff
path: root/board/ipek01/ipek01.c
diff options
context:
space:
mode:
Diffstat (limited to 'board/ipek01/ipek01.c')
-rw-r--r--board/ipek01/ipek01.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/board/ipek01/ipek01.c b/board/ipek01/ipek01.c
index ca99332e51..133db8c6bd 100644
--- a/board/ipek01/ipek01.c
+++ b/board/ipek01/ipek01.c
@@ -75,12 +75,12 @@ static void sdram_start (int hi_addr)
}
/*
* ATTENTION: Although partially referenced initdram does NOT make real
* use of CONFIG_SYS_SDRAM_BASE. The code does not work if
* CONFIG_SYS_SDRAM_BASE is something else than 0x00000000.
*/
-int initdram(void)
+int dram_init(void)
{
struct mpc5xxx_mmap_ctl *mmap_ctl =
(struct mpc5xxx_mmap_ctl *)CONFIG_SYS_MBAR;
@@ -75,12 +75,12 @@ static void sdram_start (int hi_addr)
}
/*
- * ATTENTION: Although partially referenced initdram does NOT make real
+ * ATTENTION: Although partially referenced dram_init does NOT make real
* use of CONFIG_SYS_SDRAM_BASE. The code does not work if
* CONFIG_SYS_SDRAM_BASE is something else than 0x00000000.